@@ -4,10 +4,9 @@ use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.033'; # VERSION
+our $VERSION = '0.034'; # VERSION
 
 # Dependencies
-use autodie::exception 2.14; # autodie::skip support
 use Exporter 5.57   (qw/import/);
 use File::Spec 3.40 ();
 use Carp ();
@@ -30,20 +29,17 @@ use overload (
     fallback => 1,
 );
 
-my $IS_BSD = $^O eq 'openbsd' || $^O eq 'freebsd';
+my $IS_BSD;
 
-my $TID = 0; # for thread safe atomic writes
+BEGIN { $IS_BSD = $^O eq 'openbsd' || $^O eq 'freebsd' }
 
 # if cloning, threads should already be loaded, but Win32 pseudoforks
 # don't do that so we have to be sure it's loaded anyway
-sub CLONE { require threads; threads->tid }
+my $TID = 0; # for thread safe atomic writes
 
-sub DOES {
-    return 1 if $_[1] eq 'autodie::skip'; # report errors like croak
-    UNIVERSAL->can('DOES') ? $_[0]->SUPER::DOES( $_[1] ) : $_[0]->isa( $_[1] );
-}
+sub CLONE { require threads; $TID = threads->tid }
 
-my $HAS_UU;                               # has Unicode::UTF8; lazily populated
+my $HAS_UU;  # has Unicode::UTF8; lazily populated
 
 sub _check_UU {
     eval { require Unicode::UTF8; Unicode::UTF8->VERSION(0.58); 1 };
@@ -73,16 +69,18 @@ sub _normalize_win32_path {
     return $path;
 }
 
-# we do our own autodie::exceptions to avoid wrapping built-in functions
 # flock doesn't work on NFS on BSD.  Since program authors often can't control
 # or detect that, we warn once instead of being fatal if we can detect it and
 # people who need it strict can fatalize the 'flock' category
 
-warnings::register_categories('flock') if $IS_BSD;
+#<<< No perltidy
+{ package flock; use if $IS_BSD, 'warnings::register' }
+#>>>
+
 my $WARNED_BSD_NFS = 0;
 
 sub _throw {
-    my ( $function, $args ) = @_;
+    my ( $self, $function, $file ) = @_;
     if (   $IS_BSD
         && $function eq 'flock'
         && $! =~ /operation not supported/i
@@ -94,13 +92,7 @@ sub _throw {
         }
     }
     else {
-        die autodie::exception->new(
-            function => "CORE::$function",
-            args     => $args,
-            errno    => $!,
-            context  => 'scalar',
-            return   => undef,
-        );
+        Path::Tiny::Error->throw( $function, ( defined $file ? $file : $self->[PATH] ), $! );
     }
 }
 
@@ -236,15 +228,15 @@ sub append {
     my $fh = $self->filehandle( ">>", $binmode );
 
     require Fcntl;
-    flock( $fh, Fcntl::LOCK_EX() ) or _throw( 'flock', [ $fh, Fcntl::LOCK_EX() ] );
+    flock( $fh, Fcntl::LOCK_EX() ) or $self->_throw('flock (LOCK_EX)');
 
     # Ensure we're at the end after the lock
-    seek( $fh, 0, Fcntl::SEEK_END() ) or _throw( 'seek', [ $fh, 0, Fcntl::SEEK_END() ] );
+    seek( $fh, 0, Fcntl::SEEK_END() ) or $self->_throw('seek');
 
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
 
     # For immediate flush
-    close $fh or _throw( 'close', [$fh] );
+    close $fh or $self->_throw('close');
 }
 
 sub append_raw { splice @_, 1, 0, { binmode => ":unix" }; goto &append }
@@ -281,9 +273,9 @@ sub child {
 sub children {
     my ( $self, $filter ) = @_;
     my $dh;
-    opendir $dh, $self->[PATH] or _throw( 'opendir', [ $dh, $self->[PATH] ] );
+    opendir $dh, $self->[PATH] or $self->_throw('opendir');
     my @children = readdir $dh;
-    closedir $dh or _throw( 'closedir', [$dh] );
+    closedir $dh or $self->_throw('closedir');
 
     if ( not defined $filter ) {
         @children = grep { $_ ne '.' && $_ ne '..' } @children;
@@ -340,7 +332,7 @@ sub filehandle {
 
     my $mode = $opentype . $binmode;
     my $fh;
-    open $fh, $mode, $self->[PATH] or _throw( 'open', [ $fh, $mode, $self->[PATH] ] );
+    open $fh, $mode, $self->[PATH] or $self->_throw('open ($mode)');
 
     return $fh;
 }
@@ -363,7 +355,7 @@ sub iterator {
                 $current = $dirs[0];
                 my $dh;
                 opendir( $dh, $current->[PATH] )
-                  or _throw( 'opendir', [ $dh, $current->[PATH] ] );
+                  or $self->_throw( 'opendir', $current->[PATH] );
                 $dirs[0] = $dh;
                 if ( -l $current->[PATH] && !$args->{follow_symlinks} ) {
                     # Symlink attack! It was a real dir, but is now a symlink!
@@ -394,7 +386,7 @@ sub lines {
     $binmode = ( ( caller(0) )[10] || {} )->{'open<'} unless defined $binmode;
     my $fh = $self->filehandle( "<", $binmode );
     require Fcntl;
-    flock( $fh, Fcntl::LOCK_SH() ) or _throw( 'flock', [ $fh, Fcntl::LOCK_SH() ] );
+    flock( $fh, Fcntl::LOCK_SH() ) or $self->_throw('flock (LOCK_SH)');
     my $chomp = $args->{chomp};
     # XXX more efficient to read @lines then chomp(@lines) vs map?
     if ( $args->{count} ) {
@@ -460,7 +452,8 @@ sub mkpath {
 sub move {
     my ( $self, $dst ) = @_;
 
-    return rename( $self->[PATH], $dst ) || _throw( 'rename', [ $self->[PATH], $dst ] );
+    return rename( $self->[PATH], $dst )
+      || $self->_throw( 'rename', $self->[PATH] . "' -> '$dst'" );
 }
 
 
@@ -538,7 +531,7 @@ sub remove {
 
     return 0 if !-e $self->[PATH] && !-l $self->[PATH];
 
-    return unlink $self->[PATH] || _throw( 'unlink', [ $self->[PATH] ] );
+    return unlink $self->[PATH] || $self->_throw('unlink');
 }
 
 
@@ -567,7 +560,7 @@ sub slurp {
     $binmode = ( ( caller(0) )[10] || {} )->{'open<'} unless defined $binmode;
     my $fh = $self->filehandle( "<", $binmode );
     require Fcntl;
-    flock( $fh, Fcntl::LOCK_SH() ) or _throw( 'flock', [ $fh, Fcntl::LOCK_SH() ] );
+    flock( $fh, Fcntl::LOCK_SH() ) or $self->_throw('flock (LOCK_SH)');
     if ( ( defined($binmode) ? $binmode : "" ) eq ":unix"
         and my $size = -s $fh )
     {
@@ -604,12 +597,12 @@ sub spew {
     my $temp = path( $self->[PATH] . $TID . $$ );
     my $fh = $temp->filehandle( ">", $binmode );
     require Fcntl;
-    flock( $fh, Fcntl::LOCK_EX() ) or _throw( 'flock', [ $fh, Fcntl::LOCK_EX() ] );
-    seek( $fh, 0, Fcntl::SEEK_SET() ) or _throw( 'seek', [ $fh, 0, Fcntl::SEEK_SET() ] );
-    truncate( $fh, 0 ) or _throw( 'truncate', [ $fh, 0 ] );
+    flock( $fh, Fcntl::LOCK_EX() ) or $self->_throw( 'flock (LOCK_EX)', $temp->[PATH] );
+    seek( $fh, 0, Fcntl::SEEK_SET() ) or $self->_throw( 'seek', $temp->[PATH] );
+    truncate( $fh, 0 ) or $self->_throw( 'truncate', $temp->[PATH] );
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
-    flock( $fh, Fcntl::LOCK_UN() ) or _throw( 'flock', [ $fh, Fcntl::LOCK_UN() ] );
-    close $fh or _throw( 'close', [$fh] );
+    flock( $fh, Fcntl::LOCK_UN() ) or $self->_throw( 'flock (LOCK_UN)', $temp->[PATH] );
+    close $fh or $self->_throw( 'close', $temp->[PATH] );
 
     # spewing need to follow the link
     # and replace the destination instead
@@ -636,13 +629,13 @@ sub spew_utf8 {
 sub stat {
     my $self = shift;
     require File::stat;
-    return File::stat::stat( $self->[PATH] ) || _throw( 'stat', [ $self->[PATH] ] );
+    return File::stat::stat( $self->[PATH] ) || $self->_throw('stat');
 }
 
 sub lstat {
     my $self = shift;
     require File::stat;
-    return File::stat::lstat( $self->[PATH] ) || _throw( 'lstat', [ $self->[PATH] ] );
+    return File::stat::lstat( $self->[PATH] ) || $self->_throw('lstat');
 }
 
 
@@ -653,11 +646,11 @@ sub touch {
     my ( $self, $epoch ) = @_;
     if ( !-e $self->[PATH] ) {
         my $fh = $self->openw;
-        close $fh or _throw( 'close', [$fh] );
+        close $fh or $self->_throw('close');
     }
     $epoch = defined($epoch) ? $epoch : time();
     utime $epoch, $epoch, $self->[PATH]
-      or _throw( 'utime', [ $epoch, $epoch, $self->[PATH] ] );
+      or $self->_throw("utime ($epoch)");
     return $self;
 }
 
@@ -676,6 +669,19 @@ sub volume {
     return $self->[VOL];
 }
 
+package Path::Tiny::Error;
+
+our @CARP_NOT = qw/Path::Tiny/;
+
+use overload ( q{""} => sub { (shift)->{msg} }, fallback => 1 );
+
+sub throw {
+    my ( $class, $op, $file, $err ) = @_;
+    chomp( my $trace = Carp::shortmess );
+    my $msg = "Error $op on '$file': $err$trace\n";
+    die bless { op => $op, file => $file, err => $err, msg => $msg }, $class;
+}
+
 1;
 
 
@@ -693,7 +699,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
@@ -756,8 +762,6 @@ The C<*_utf8> methods (C<slurp_utf8>, C<lines_utf8>, etc.) operate in raw
 mode without CRLF translation.  Installing L<Unicode::UTF8> 0.58 or later
 will speed up several of them and is highly recommended.
 
-It uses L<autodie> internally, so most failures will be thrown as exceptions.
-
 =head1 CONSTRUCTORS
 
 =head2 path
@@ -1208,6 +1212,34 @@ usually is the empty string on Unix-like operating systems.
 openr_raw opena_raw openw_raw openrw_raw
 DOES
 
+=head1 EXCEPTION HANDLING
+
+Failures will be thrown as exceptions in the class C<Path::Tiny::Error>.
+
+The object will be a hash reference with the following fields:
+
+=over 4
+
+=item *
+
+C<op> — a description of the operation, usually function call and any extra info
+
+=item *
+
+C<file> — the file or directory relating to the error
+
+=item *
+
+C<err> — hold C<$!> at the time the error was thrown
+
+=item *
+
+C<msg> — a string combining the above data and a Carp-like short stack trace
+
+=back
+
+Exception objects will stringify as the C<msg> field.
+
 =head1 CAVEATS
 
 =head2 NFS and BSD
